import ModuleTitle from '@/components/ManagementPage/moduleTitle';
import TabsContent from '@/components/TabsContent';
import ThresholdDetail from '@/components/ThresholdDetail';
import ThresholdModal from '@/components/ThresholdDetail/ThresholdModal';
import { changeRecordStatus, getDumuDetail } from '@/services/eqSelfInspection';
import { UnityAction } from '@/utils/utils';
import { connect, useRequest } from '@umijs/max';
import {
  Checkbox,
  Col,
  DatePicker,
  Form,
  Input,
  Modal,
  Row,
  Select,
  Spin,
  Table,
  message,
} from 'antd';
import dayjs from 'dayjs';
import { useEffect, useMemo, useState } from 'react';
import ReactZmage from 'react-zmage';
import styles from './PatrolReportDetail.less';

function Detail(props) {
  const { data, userList, projectId, dispatch, loading = false } = props;

  const [select, setSelect] = useState();
  const [statusCheck, setStatusCheck] = useState([0, 1, 2]);

  const sendMessageToUnity = (select, data) => {
    setSelect(select);
    if (window.HightlightEquipment) {
      window.HightlightEquipment(data);
    }
  };

  const result = useMemo(() => {
    var resultArr = [];
    var tempResult = data?.PatrolResult;
    var tempArr = tempResult?.split(';');
    const getTextColor = (status) => {
      switch (status) {
        case '警告':
          return {
            color: '#FFE26D',
            className: styles.warn,
          };
        case '异常':
          return {
            color: '#FE5850',
            className: styles.error,
          };

        default:
          return {
            color: '#12CEB3',
            className: '',
          };
      }
    };
    if (tempArr?.length > 0) {
      tempArr?.forEach((item, index) => {
        var tempItem = item;
        var itemSplit = tempItem.split('：');
        if (itemSplit?.length > 1) {
          var label = '';
          var value = itemSplit[1];
          if (index === 0) label = '设备自检';
          else if (index === 1) label = '工艺自检';
          else {
            label = '安全自检';
            value =
              data?.secureStatus === 0
                ? itemSplit[1] !== '异常'
                  ? '正常'
                  : '异常'
                : '异常';
          }
          resultArr.push({
            ...getTextColor(value),
            label,
            value,
          });
        }
      });
    }
    return resultArr;
  }, [data]);

  useEffect(() => {
    dispatch({
      type: 'eqSelfInspection/fetchUserList',
      payload: {
        projectId,
      },
    });
  }, []);

  return (
    <Spin spinning={loading}>
      <div className={styles.card}>
        <Row>
          <Col span={24} className={styles.cardText}>
            自检时间：{data?.CreatedTime}
          </Col>
        </Row>
        <Row>
          <Col span={8} className={styles.cardText}>
            自检路线：{data?.RouteInfo?.Name}
          </Col>
          <Col span={8} className={styles.cardText}>
            工艺段：{data?.RouteInfo?.GroupID}
          </Col>
        </Row>
        <Row>
          {result.map((item, index) => (
            <Col span={8} className={styles.cardText}>
              {index == 0 && '自检结果：'}
              {item.label}-
              <span style={{ color: item.color }}>{item.value}</span>
            </Col>
          ))}
        </Row>
      </div>
      <div>
        <Checkbox.Group
          onChange={(check) => {
            // 未勾选则认为全部显示
            if (check.length == 0) {
              setStatusCheck([1, 2, 3]);
            } else {
              setStatusCheck(check);
            }
          }}
          style={{
            width: '70%',
            margin: '0 auto',
            display: 'flex',
            justifyContent: 'center',
            marginBottom: '0.3rem',
          }}
        >
          <Checkbox value={1}>异常数据</Checkbox>
          <Checkbox value={2} style={{ margin: '0 0.5rem' }}>
            警告数据
          </Checkbox>
          <Checkbox value={0}>正常数据</Checkbox>
        </Checkbox.Group>
        {/* 设备自检报告 */}
        <DeviceReport
          sendMessageToUnity={sendMessageToUnity}
          select={select}
          data={data}
          userList={userList}
          statusCheck={statusCheck}
        />

        {/* 工艺自检报告 */}

        <AalysisTable
          onClickItem={sendMessageToUnity}
          select={select}
          data={data}
          statusCheck={statusCheck}
        />
        {/* 安全自检报告 */}
        <SecureReport
          sendMessageToUnity={sendMessageToUnity}
          select={select}
          data={data}
          userList={userList}
          statusCheck={statusCheck}
        />
      </div>
      {/* </Card> */}
    </Spin>
  );
}

export function DeviceTable(props) {
  const {
    onClickItem,
    data = {},
    items,
    onErrorHandle,
    select,
    userList,
    type,
  } = props;
  console.log(items);
  const { ProjectId, Id } = data;
  const [loading, setLoading] = useState(false);
  const [visible, setVisible] = useState(false);
  const [errVisible, setErrVisible] = useState(false);
  const [currentItem, setCurrentItem] = useState({});
  const isSensor = type == 'sensor';

  const onClickThreshold = (record) => {
    setCurrentItem(record);
    setVisible(true);
  };
  const onClickError = (record) => {
    setCurrentItem(record);
    setErrVisible(true);
  };
  const handleError = async (values) => {
    setLoading(true);
    let res = await changeRecordStatus({
      ...values,
      Id: currentItem.Id,
      DeviceCode: currentItem.DeviceCode,
      DeviceName: currentItem.DeviceName,
      RecordId: data.Id,
      RepairMan: values.RepairMan * 1,
    });
    setLoading(false);
    if (res) {
      message.success('操作成功');
      setErrVisible(false);
    }
  };
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'DeviceName',
    },
    {
      title: '巡检项',
      key: 'TemplateItem.Name',
      dataIndex: ['TemplateItem', 'Name'],
    },
    // {
    //   title: '设备位号',
    //   width: '16%',
    //   dataIndex: 'DeviceCode',
    // },
    {
      title: '设定值范围',
      render: (record) => (
        <ThresholdDetail
          current={record.Value || 0}
          data={record || {}}
          // onClick={() => onClickThreshold(record)}
        />
      ),
    },
    {
      title: '状态',
      dataIndex: 'Status',
      width: '1.25rem',
      render: (Status) => {
        switch (Status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                ></i>
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FE5850' }}
                ></i>
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                ></i>
                警告
              </div>
            );
        }
      },
    },
  ];
  const handleClickItem = (data) => {
    if (!isSensor) {
      onClickItem(`DeviceTable-${data.Id}`, {
        type: data.Status,
        deviceCode: data.DeviceCode,
      });
    } else {
      onClickItem(`DeviceTable-${data.Id}`, {
        // type: data.Status,
        deviceCode: data.DeviceCode,
        value: Number(data.Value || 0),
        threshold: data.JsonNumThreshold,
      });
      UnityAction.sendMsg('SinglePowerEnvironFromWeb', JSON.stringify(data));
    }
  };

  // useEffect(() => {
  //   console.log('温控', items);
  //   if (isSensor)
  //     UnityAction.sendMsg('PowerEnvironsFromWeb', JSON.stringify(items));
  // }, [items]);

  // if (!isSensor) {
  //   columns.push({
  //     title: '操作',
  //     render: (record) =>
  //       record.Status == 1 && (
  //         <a style={{ color: '#FE5850' }} onClick={() => onClickError(record)}>
  //           异常处理
  //         </a>
  //       ),
  //   });
  // }

  return (
    <div>
      <Table
        columns={columns}
        dataSource={items}
        rowKey="Id"
        locale={{
          emptyText: <Empty />,
        }}
        pagination={false}
      />
      <ThresholdModal
        open={visible}
        data={currentItem.JsonNumThreshold}
        onClose={() => setVisible(false)}
      />
      <ErrorHandleModal
        open={errVisible}
        userList={userList}
        onCancel={() => setErrVisible(false)}
        onOk={handleError}
      />
    </div>
  );
}

function DeviceReport(props) {
  const { data } = props;

  // 子集是否显示
  const [subStatus, setSubStatus] = useState([1, 1, 1, 1, 1, 1]);

  const subProps = { ...props, setSubStatus };

  // 子集全部隐藏的情况下，父级也隐藏
  const show = useMemo(() => {
    let total = subStatus.reduce((item, total) => (total += item), 0);
    return total > 0;
  }, [subStatus]);

  const changeStatus = (type, status) => {
    setSubStatus((subStatus) => {
      let newSubStatus = [...subStatus];
      newSubStatus[type] = status;
      return newSubStatus;
    });
  };

  // if (!show) return null;

  return (
    <div style={{ display: show ? 'block' : 'none' }}>
      <ModuleTitle title="设备自检报告" />

      {/* 设备自检报告 */}
      <ReportCom
        {...subProps}
        allData={data?.extendWarningAllData}
        key="extend"
        type={'extend'}
        title={<div id="device">设备自检</div>}
        changeStatus={(status) => changeStatus(0, status)}
      ></ReportCom>

      {/* 液位校验 */}
      <LiquidLevelCom
        {...subProps}
        allData={data?.FluidLevelList}
        key="liquid"
        type={'liquid'}
        title="液位校验"
        changeStatus={(status) => changeStatus(1, status)}
      />
      {/* 加药流量校验 */}
      <DosingFlowCom
        {...subProps}
        allData={data?.FluidLevelList}
        title="加药流量校验"
        changeStatus={(status) => changeStatus(2, status)}
      />
      <WaterInCom
        {...subProps}
        allData={data?.WaterInCheckList}
        title="进出水流量校验"
        changeStatus={(status) => changeStatus(3, status)}
      />
      <PressureGaugeCom
        {...subProps}
        allData={data?.PressureCompareList}
        title="压力仪表校验"
        changeStatus={(status) => changeStatus(4, status)}
      />
      <WaterQualityCom
        {...subProps}
        allData={data?.WaterQualityCompareList}
        title="水质仪表校验"
        changeStatus={(status) => changeStatus(5, status)}
      />
    </div>
  );
}

function SecureReport(props) {
  const { data } = props;
  const [dumuList, setDumuList] = useState([]);
  // 子集是否显示
  const [subStatus, setSubStatus] = useState([1, 1, 1]);

  const subProps = { ...props, setSubStatus };

  // 子集全部隐藏的情况下，父级也隐藏
  const show = useMemo(() => {
    let total = subStatus.reduce((item, total) => (total += item), 0);
    return total > 0;
  }, [subStatus]);

  const changeStatus = (type, status) => {
    setSubStatus((subStatus) => {
      let newSubStatus = [...subStatus];
      newSubStatus[type] = status;
      return newSubStatus;
    });
  };

  const { run: detailRun } = useRequest(getDumuDetail, {
    manual: true,
    fetchKey: (id) => id,
    onSuccess: (data) => {
      var item = dumuList?.find((child) => child.id === data.id);
      if (item) {
        item.url = base64ToImageUrl(data.event_bg);
      }
      setDumuList([...dumuList]);
    },
  });
  useEffect(() => {
    setDumuList(data?.dumuList);
    data?.dumuList?.map((item) => {
      detailRun(item.id);
    });
  }, [data?.dumuList]);

  // if (!show) return null;

  return (
    <div
      id="secure"
      className={styles.content}
      style={{ display: show ? 'block' : 'none' }}
    >
      <ModuleTitle title="安全自检报告" />
      {/* 环境异常 */}
      <ReportCom
        {...subProps}
        allData={data?.sensor}
        data={data?.sensorWaringData}
        key="sensor"
        type={'sensor'}
        title={'环境自检'}
        changeStatus={(status) => changeStatus(0, status)}
      ></ReportCom>
      {/* 液位校验 */}
      {/* <LiquidLevelCom
      sendMessageToUnity={sendMessageToUnity}
      select={select}
      allData={data?.FluidLevelList}
      key="liquid"
      type={'liquid'}
      userList={userList}
      title={<ModuleTitle title="液位校验" />}
    /> */}

      {/* 安防检测异常 */}
      <ReportDumCom
        {...subProps}
        data={dumuList}
        title={'安防自检'}
        changeStatus={(status) => changeStatus(1, status)}
      />

      {/* 电器检测异常 */}
      {/* <ReportCom
      sendMessageToUnity={sendMessageToUnity}
      select={select}
      waringData={[]}
      allData={[]}
      key="extend"
      type={'extend'}
      userList={userList}
      title={'电气检测异常'}
    ></ReportCom> */}

      {/* 密闭空间检测异常 */}
      <ReportCom
        {...subProps}
        key="extend"
        type={'extend'}
        title={'密闭空间自检'}
        changeStatus={(status) => changeStatus(2, status)}
      ></ReportCom>
    </div>
  );
}

function AalysisTable(props) {
  const { data = {}, statusCheck } = props;
  const { FaultAnalysis } = data;
  const errorCount = data?.FaultAnalysis?.length || 0;
  const columns = [
    {
      title: '异常名称',
      width: '18%',
      dataIndex: 'device_name',
    },
    // {
    //   title: '位号',
    //   width: '15%',
    //   dataIndex: 'device_code',
    // },
    {
      title: '可能原因',
      width: '30%',
      render: (record) => record.reason,
    },
    {
      title: '解决方案',
      width: '52%',
      render: (record) => {
        if (record.fix_plan instanceof Array) {
          return (
            <div>
              {record.fix_plan.map((item) => (
                <div>
                  {item.content}
                  <br />
                </div>
              ))}
            </div>
          );
        } else {
          return record.fix_plan;
        }
      },
    },
  ];

  if (statusCheck.length != 3) {
    // 不显示异常数据时，隐藏次模块
    if (!statusCheck.includes(1)) return null;
    // 过滤异常并且此模块没有异常数据时，不显示此模块
    if (statusCheck.includes(1) && errorCount == 0) return null;
  }

  return (
    <div className={styles.content} id="technology">
      <div className={styles.tableStatus}>异常({errorCount})</div>
      <ModuleTitle title="工艺自检报告" />
      <Table
        columns={columns}
        dataSource={FaultAnalysis}
        rowKey="device_code"
        locale={{
          emptyText: <Empty />,
        }}
        pagination={false}
      />
    </div>
  );
}

function ErrorHandleModal(props) {
  const { visible, onCancel, onOk, userList } = props;
  const [form] = Form.useForm();
  const status = form.getFieldValue('Status');
  const handleOk = () => {
    form.validateFields((error, values) => {
      if (error) return;
      onOk({
        ...values,
        PlanTime: values?.PlanTime?.format('YYYY-MM-DD HH:mm:ss'),
      });
    });
  };

  return (
    <Modal
      title="异常处理"
      open={visible}
      onCancel={onCancel}
      onOk={handleOk}
      destroyOnClose
    >
      <Form labelCol={{ span: 7 }} wrapperCol={{ span: 16 }}>
        <Form.Item label="异常处理备注" name="ExceptionHandling">
          <Input.TextArea />
        </Form.Item>
        <Form.Item
          label="审核状态"
          name="Status"
          rules={[{ required: true, message: '请选择验收状态' }]}
        >
          <Select style={{ width: '100%' }} placeholder="请选择验收状态">
            <Select.Option value={1}>已派遣</Select.Option>
            <Select.Option value={2}>已通过</Select.Option>
          </Select>
        </Form.Item>
        <Form.Item
          label="维修人"
          name="RepairMan"
          rules={[{ required: true, message: '请选择维修人' }]}
        >
          <Select
            showSearch
            placeholder="请选择维修人"
            filterOption={(input, option) =>
              option.props.children.indexOf(input) >= 0
            }
            style={{ width: '100%' }}
          >
            {userList?.map((item) => (
              <Select.Option key={item.ID}>{item.CName}</Select.Option>
            ))}
          </Select>
        </Form.Item>
        {status == 1 && (
          <>
            <Form.Item
              label="难度级别"
              name="DifficultyLevel"
              rules={[{ required: true, message: '请选择难度级别' }]}
            >
              <Select placeholder="请选择难度级别" style={{ width: '100%' }}>
                <Select.Option value={0}>大修</Select.Option>
                <Select.Option value={1}>项目维修</Select.Option>
                <Select.Option value={2}>小修</Select.Option>
              </Select>
            </Form.Item>
            <Form.Item
              label="维修方式"
              name="RepairType"
              rules={[{ required: true, message: '请选择维修方式' }]}
            >
              <Select placeholder="请选择维修方式" style={{ width: '100%' }}>
                <Select.Option value={0}>自维</Select.Option>
                <Select.Option value={1}>外委</Select.Option>
              </Select>
            </Form.Item>
            <Form.Item
              label="计划完成日期"
              name="PlanTime"
              rules={[{ required: true, message: '请选择计划完成日期' }]}
            >
              <DatePicker inputReadOnly />
            </Form.Item>
          </>
        )}
      </Form>
    </Modal>
  );
}

export function WarningTable(props) {
  const { data, userList, items } = props;
  const [loading, setLoading] = useState(false);
  const [visible, setVisible] = useState(false);
  const [errVisible, setErrVisible] = useState(false);
  const [currentItem, setCurrentItem] = useState({});

  const handleError = async (values) => {
    setLoading(true);
    var res = await changeRecordStatus({
      ...values,
      Id: currentItem.Id,
      DeviceCode: currentItem.DeviceCode,
      DeviceName: currentItem.DeviceName,
      RecordId: data.Id,
      RepairMan: values.RepairMan * 1,
    });
    setLoading(false);
    if (res) {
      message.success('操作成功');
      setErrVisible(false);
    }
  };
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'DeviceName',
    },
    {
      title: '巡检项',
      dataIndex: ['TemplateItem', 'Name'],
    },
    {
      title: '设定值范围',
      width: '30%',
      render: (record) => (
        <ThresholdDetail current={record.Value || 0} data={record || {}} />
      ),
    },
    {
      title: '状态',
      dataIndex: 'Status',
      width: '1.25rem',
      render: (Status) => {
        switch (Status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                ></i>
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FE5850' }}
                ></i>
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                ></i>
                警告
              </div>
            );
        }
      },
    },
  ];

  // if (!isSensor) {
  //   columns.push({
  //     title: '操作',
  //     render: (record) =>
  //       record.Status == 1 && (
  //         <a style={{ color: '#FE5850' }} onClick={() => onClickError(record)}>
  //           异常处理
  //         </a>
  //       ),
  //   });
  // }

  // useEffect(() => {
  //   if (isSensor)
  //     UnityAction.sendMsg('PowerEnvironsFromWeb', JSON.stringify(items));
  // }, [items]);

  return (
    <div>
      <Table
        columns={columns}
        dataSource={items}
        rowKey="Id"
        locale={{
          emptyText: <Empty />,
        }}
        pagination={false}
      />
      <ThresholdModal
        open={visible}
        data={currentItem.JsonNumThreshold}
        onClose={() => setVisible(false)}
      />
      <ErrorHandleModal
        open={errVisible}
        userList={userList}
        onCancel={() => setErrVisible(false)}
        onOk={handleError}
      />
    </div>
  );
}

function ReportCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData,
    userList,
    type,
    title,
    data,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');
  const handleTabsChange = (activeKey) => {
    setActiveKey(activeKey);
  };

  const { warningTableData, errorTableData, normalData } = useMemo(() => {
    let data = { warningTableData: [], errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.Status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.Status == 2 && statusCheck.includes(2)) {
        data.warningTableData.push(item);
      } else if (statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || warningTableData.length > 0) {
      items.push({
        key: '2',
        label: `警告(${warningTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `正常(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;

  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small={true}
          items={items}
        ></TabsContent>
      </div>

      {activeKey == '1' && (
        <WarningTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
          key={type}
          data={data}
          type={type}
          userList={userList}
        />
      )}
      {activeKey == '2' && (
        <WarningTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={warningTableData}
          key={type}
          data={data}
          type={type}
          userList={userList}
        />
      )}
      {activeKey == '0' && (
        <DeviceTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={allData}
          data={data}
          key={type}
          type={type}
          userList={userList}
        />
      )}
    </div>
  );
}

export function LiquidTable(props) {
  const { onClickItem, data = {}, items, select, type } = props;
  const { ProjectId, Id } = data;
  const [loading, setLoading] = useState(false);
  const [currentItem, setCurrentItem] = useState({});

  const columns = [
    {
      title: '设备名称',
      width: '12%',
      dataIndex: 'device_name',
    },
    {
      title: '时间',
      dataIndex: 'record_time',
      render: (text) => {
        if (text) {
          return dayjs(text).format('YYYY.MM.DD HH:mm');
        }
        return '-';
      },
    },
    {
      title: '类型',
      key: 'template_item_name',
      dataIndex: 'template_item_name',
    },
    {
      title: '液位数',
      dataIndex: 'origin_value',
    },
    {
      title: '差值/比值',
      dataIndex: 'value',
    },
    {
      title: '设定值范围',
      width: '18%',
      render: (record) => (
        <ThresholdDetail
          current={record.value || 0}
          data={{
            JsonNumThreshold: record?.json_num_threshold,
            Type: record.type || 2,
          }}
        />
      ),
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: '1.25rem',
      render: (status) => {
        switch (status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                ></i>
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                ></i>
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                ></i>
                警告
              </div>
            );
        }
      },
    },
  ];
  const handleClickItem = (data) => {
    onClickItem(`DeviceTable-${data.device_code}`, {
      type: data.status,
      deviceCode: data.device_code,
    });
  };

  return (
    <Table
      columns={columns}
      dataSource={items}
      rowKey="device_code"
      locale={{
        emptyText: <Empty />,
      }}
      pagination={false}
    />
  );
}

function LiquidLevelCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData,
    type,
    title,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');

  const handleTabsChange = (activeKey) => {
    setActiveKey(activeKey);
  };

  const { errorTableData, normalData } = useMemo(() => {
    let data = { errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.status == 0 && statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `历史记录(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;

  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small
          items={items}
        ></TabsContent>
      </div>

      {activeKey === '1' && (
        <LiquidTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
          key={type}
          type={type}
        />
      )}
      {activeKey === '0' && (
        <LiquidTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={normalData}
          key={type}
          type={type}
        />
      )}
    </div>
  );
}

function DosingFlowTable(props) {
  const { onClickItem, data = {}, items } = props;
  const columns = [
    {
      title: '设备名称',
      width: '12%',
      dataIndex: 'device_name',
    },
    {
      title: '时间',
      dataIndex: 'record_time',
      render: (text) => {
        if (text) {
          return dayjs(text).format('YYYY.MM.DD HH:mm');
        }
        return '-';
      },
    },
    {
      title: '类型',
      width: '15%',
      key: 'template_item_name',
      dataIndex: 'template_item_name',
    },
    {
      title: '实际流量',
      dataIndex: 'origin_value',
    },
    {
      title: '计量流量',
      dataIndex: 'value',
    },
    {
      title: '差值/比值',
      dataIndex: 'value',
    },
    {
      title: '设定值范围',
      width: '18%',
      render: (record) => (
        <ThresholdDetail
          current={record.value || 0}
          data={{
            JsonNumThreshold: record?.json_num_threshold,
            Type: record.type || 2,
          }}
        />
      ),
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: '20%',
      render: (status) => {
        switch (status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                />
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                />
                警告
              </div>
            );
          default:
            return null;
        }
      },
    },
  ];
  const handleClickItem = (data) => {
    onClickItem(`DeviceTable-${data.device_code}`, {
      type: data.status,
      deviceCode: data.device_code,
    });
  };

  return (
    <Table
      columns={columns}
      dataSource={items}
      rowKey="device_code"
      locale={{
        emptyText: <Empty />,
      }}
      pagination={false}
    />
  );
}

function DosingFlowCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData = [],
    title,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');

  const handleTabsChange = (key) => {
    setActiveKey(key);
  };

  const { errorTableData, normalData } = useMemo(() => {
    let data = { errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.status == 0 && statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `历史记录(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;

  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small
          items={items}
        ></TabsContent>
      </div>

      {activeKey === '1' && (
        <DosingFlowTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
        />
      )}
      {activeKey === '0' && (
        <DosingFlowTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={normalData}
        />
      )}
    </div>
  );
}

function WaterInTable(props) {
  const { onClickItem, data = {}, items } = props;
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'item_alias',
    },
    {
      title: '差值',
      // width: '15%',
      dataIndex: 'current_val',
    },
    {
      title: '时间',
      // width: '15%',
      dataIndex: 'create_time',
      render: (text) => {
        if (text) {
          return dayjs(text).format('HH:mm:ss');
        }
        return '-';
      },
    },
    {
      title: '设定值范围',
      width: '30%',
      render: (record) => (
        <ThresholdDetail
          current={record.current_val || 0}
          data={{
            JsonNumThreshold: {
              exception: [
                { ThresholdValue: record?.thresholds, ThresholdType: 1 },
              ],
            },
            Type: 2,
          }}
        />
      ),
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: '1.25rem',
      render: (status) => {
        switch (status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                />
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                />
                警告
              </div>
            );
          default:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
        }
      },
    },
  ];
  const handleClickItem = (params) => {
    onClickItem(`DeviceTable-${params.device_code}`, {
      type: params.status,
      deviceCode: params.device_code,
    });
  };

  return (
    <Table
      columns={columns}
      dataSource={items}
      rowKey="device_code"
      locale={{
        emptyText: <Empty />,
      }}
      pagination={false}
    />
  );
}

function WaterInCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData = [],
    title,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');

  const handleTabsChange = (key) => {
    setActiveKey(key);
  };

  const { errorTableData, normalData } = useMemo(() => {
    let data = { errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.status == 0 && statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `正常(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;
  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small
          items={items}
        ></TabsContent>
      </div>
      {activeKey === '1' && (
        <WaterInTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
        />
      )}
      {activeKey === '0' && (
        <WaterInTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={normalData}
        />
      )}
    </div>
  );
}

function PressureGaugeTable(props) {
  const { onClickItem, data = {}, items } = props;
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'item_alias',
    },
    {
      title: '时间范围',
      key: 'dataRange',
      width: '1.5rem',
      render: (record) => {
        if (record.query_start && record.query_end) {
          return (
            <>
              {dayjs(record.query_start).format('HH:mm:ss')}
              <br />
              {dayjs(record.query_end).format('HH:mm:ss')}
            </>
          );
        }
        return '-';
      },
    },
    {
      title: (
        <>
          仪表
          <br />
          最小数
        </>
      ),
      width: '1.25rem',
      dataIndex: 'data_min',
    },
    {
      title: (
        <>
          仪表
          <br />
          最大数
        </>
      ),
      width: '1.25rem',
      dataIndex: 'data_max',
    },
    {
      title: '可能原因',
      dataIndex: 'content',
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: '1.25rem',
      render: (status) => {
        switch (status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                />
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                />
                警告
              </div>
            );
          default:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
        }
      },
    },
  ];
  const handleClickItem = (params) => {
    onClickItem(`DeviceTable-${params.device_code}`, {
      type: params.status,
      deviceCode: params.device_code,
    });
  };

  return (
    <Table
      columns={columns}
      dataSource={items}
      rowKey="device_code"
      locale={{
        emptyText: <Empty />,
      }}
      pagination={false}
    />
  );
}

function PressureGaugeCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData = [],
    title,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');

  const handleTabsChange = (key) => {
    setActiveKey(key);
  };

  const { errorTableData, normalData } = useMemo(() => {
    let data = { errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.status == 0 && statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `正常(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;
  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small
          items={items}
        ></TabsContent>
      </div>
      {activeKey === '1' && (
        <PressureGaugeTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
        />
      )}
      {activeKey === '0' && (
        <PressureGaugeTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={normalData}
        />
      )}
    </div>
  );
}

function WaterQualityTable(props) {
  const { onClickItem, data = {}, items } = props;
  const columns = [
    {
      title: '设备名称',
      width: '20%',
      dataIndex: 'item_alias',
    },
    {
      title: '时间范围',
      key: 'dataRange',
      width: '1.5rem',
      render: (record) => {
        if (record.query_start && record.query_end) {
          return (
            <>
              {dayjs(record.query_start).format('HH:mm:ss')}
              <br />
              {dayjs(record.query_end).format('HH:mm:ss')}
            </>
          );
        }
        return '-';
      },
    },
    {
      title: (
        <>
          仪表
          <br />
          最小数
        </>
      ),
      width: '1.25rem',
      dataIndex: 'data_min',
    },
    {
      title: (
        <>
          仪表
          <br />
          最大数
        </>
      ),
      width: '1.25rem',
      dataIndex: 'data_max',
    },
    {
      title: '可能原因',
      dataIndex: 'content',
    },
    {
      title: '状态',
      dataIndex: 'status',
      width: '1.25rem',
      render: (status) => {
        switch (status) {
          case -1:
          case 0:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#12CEB3' }}
                />
                正常
              </div>
            );
          case 1:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
          case 2:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FFE26D' }}
                />
                警告
              </div>
            );
          default:
            return (
              <div>
                <i
                  className={styles.iconStatus}
                  style={{ background: '#FF8600' }}
                />
                异常
              </div>
            );
        }
      },
    },
  ];
  const handleClickItem = (params) => {
    onClickItem(`DeviceTable-${params.device_code}`, {
      type: params.status,
      deviceCode: params.device_code,
    });
  };

  return (
    <Table
      columns={columns}
      dataSource={items}
      rowKey="device_code"
      locale={{
        emptyText: <Empty />,
      }}
      pagination={false}
    />
  );
}

function WaterQualityCom(props) {
  const {
    sendMessageToUnity,
    select,
    allData = [],
    title,
    statusCheck,
    changeStatus,
  } = props;
  const [activeKey, setActiveKey] = useState('1');

  const handleTabsChange = (key) => {
    setActiveKey(key);
  };

  const { errorTableData, normalData } = useMemo(() => {
    let data = { errorTableData: [], normalData: [] };
    allData?.forEach((item) => {
      if (item.status == 1 && statusCheck.includes(1)) {
        data.errorTableData.push(item);
      } else if (item.status == 0 && statusCheck.includes(0)) {
        data.normalData.push(item);
      }
    });
    return data;
  }, [statusCheck, allData]);

  const items = useMemo(() => {
    let items = [];
    let showAllTabs = statusCheck.length == 3;
    if (showAllTabs || errorTableData.length > 0) {
      items.push({
        key: '1',
        label: `异常(${errorTableData.length || 0})`,
        children: <div></div>,
      });
    }
    if (showAllTabs || normalData.length > 0) {
      items.push({
        key: '0',
        label: `正常(${normalData.length || 0})`,
        children: <div></div>,
      });
    }
    return items;
  }, [statusCheck, allData]);

  useEffect(() => {
    if (items.length == 0) {
      changeStatus(0);
    } else {
      setActiveKey(items[0].key);
      changeStatus(1);
    }
  }, [items]);

  if (items.length == 0) return null;

  return (
    <div className={styles.detailCard}>
      <div className={styles.tableTop}>
        {title}
        <TabsContent
          active={activeKey}
          onChange={handleTabsChange}
          small
          items={items}
        ></TabsContent>
      </div>
      {activeKey === '1' && (
        <WaterQualityTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={errorTableData}
        />
      )}
      {activeKey === '0' && (
        <WaterQualityTable
          onClickItem={sendMessageToUnity}
          select={select}
          items={normalData}
        />
      )}
    </div>
  );
}

function ReportDumCom(props) {
  const { data = [], title, statusCheck, changeStatus } = props;
  const errorCount = data?.length || 0;
  const columns = [
    {
      title: '报警时间',
      dataIndex: 'event_time',
      render: (time) => dayjs(time).format('YYYY-MM-DD HH:mm:ss'),
    },
    {
      title: '设备名称',
      dataIndex: 'device_name',
    },
    {
      title: '报警类型',
      dataIndex: 'event_type',
      // render: type => alarmType[type],
    },
    {
      title: '报警图片',
      render: (item) => (
        <ReactZmage
          controller={{
            // 关闭按钮
            close: true,
            // 旋转按钮
            rotate: true,
            // 缩放按钮
            zoom: false,
            // 下载按钮
            download: false,
            // 翻页按钮
            flip: false,
            // 多页指示
            pagination: false,
          }}
          backdrop="rgba(255,255,255,0.5)"
          style={{ height: '0.9rem' }}
          src={item.path}
        />
      ),
    },
  ];

  const show = useMemo(() => {
    if (statusCheck.length != 3) {
      // 不显示异常数据时，隐藏次模块
      if (!statusCheck.includes(1)) return null;
      // 过滤异常并且此模块没有异常数据时，不显示此模块
      if (statusCheck.includes(1) && errorCount == 0) return null;
    }
    return true;
  }, [statusCheck, errorCount]);

  useEffect(() => {
    if (show) {
      changeStatus(1);
    } else {
      changeStatus(0);
    }
  }, [show]);

  if (!show) return null;
  return (
    <div style={{ marginBottom: '0.3rem' }}>
      <div className={styles.tabBarExtraContent}>
        <div className={styles.text} style={{ width: '60%' }}>
          {title}
        </div>
        <div className={styles.abnormal}>
          <div className={styles.text} style={{ float: 'right' }}>
            异常({errorCount})
          </div>
        </div>
      </div>
      <Table
        bordered
        rowKey="event_time"
        columns={columns}
        dataSource={data}
        locale={{
          emptyText: <Empty />,
        }}
        pagination={false}
      />
    </div>
  );
}

function base64ToImageUrl(base64String) {
  const byteCharacters = atob(base64String);
  const byteArrays = [];

  for (let i = 0; i < byteCharacters.length; i++) {
    byteArrays.push(byteCharacters.charCodeAt(i));
  }

  const byteArray = new Uint8Array(byteArrays);
  const blob = new Blob([byteArray], { type: 'image/png' });
  const imageUrl = URL.createObjectURL(blob);

  return imageUrl;
}

function Empty() {
  return (
    <div>
      <img
        src={require('@/assets/self-empty.png')}
        style={{ margin: '0.2rem 0', width: '1rem' }}
      />
      <p style={{ textAlign: 'center', color: '#555' }}>自检正常</p>
    </div>
  );
}

export default connect(({ eqSelfInspection }) => ({
  userList: eqSelfInspection.userList,
  mandateInfo: eqSelfInspection.mandateInfo,
}))(Detail);
